{{ fullname | escape | underline }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ name }}
  :members:
  :undoc-members:
  :special-members:
  :private-members:

  .. autoclasstoc::
  .. rubric:: Full Documentation:
